@@ -6,6 +6,60 @@ static void _c_callback_cleanup(void *userdata)
 	_Gio_go_callback_cleanup(userdata);
 }
 
+extern void _GBaseFinalizeFunc_c_wrapper();
+extern void _GBaseFinalizeFunc_c_wrapper_once();
+extern void _GBaseInitFunc_c_wrapper();
+extern void _GBaseInitFunc_c_wrapper_once();
+extern void _GBindingTransformFunc_c_wrapper();
+extern void _GBindingTransformFunc_c_wrapper_once();
+extern void _GBoxedCopyFunc_c_wrapper();
+extern void _GBoxedCopyFunc_c_wrapper_once();
+extern void _GBoxedFreeFunc_c_wrapper();
+extern void _GBoxedFreeFunc_c_wrapper_once();
+extern void _GCallback_c_wrapper();
+extern void _GCallback_c_wrapper_once();
+extern void _GClassFinalizeFunc_c_wrapper();
+extern void _GClassFinalizeFunc_c_wrapper_once();
+extern void _GClassInitFunc_c_wrapper();
+extern void _GClassInitFunc_c_wrapper_once();
+extern void _GClosureMarshal_c_wrapper();
+extern void _GClosureMarshal_c_wrapper_once();
+extern void _GClosureNotify_c_wrapper();
+extern void _GClosureNotify_c_wrapper_once();
+extern void _GInstanceInitFunc_c_wrapper();
+extern void _GInstanceInitFunc_c_wrapper_once();
+extern void _GInterfaceFinalizeFunc_c_wrapper();
+extern void _GInterfaceFinalizeFunc_c_wrapper_once();
+extern void _GInterfaceInitFunc_c_wrapper();
+extern void _GInterfaceInitFunc_c_wrapper_once();
+extern void _GObjectFinalizeFunc_c_wrapper();
+extern void _GObjectFinalizeFunc_c_wrapper_once();
+extern void _GObjectGetPropertyFunc_c_wrapper();
+extern void _GObjectGetPropertyFunc_c_wrapper_once();
+extern void _GObjectSetPropertyFunc_c_wrapper();
+extern void _GObjectSetPropertyFunc_c_wrapper_once();
+extern void _GSignalAccumulator_c_wrapper();
+extern void _GSignalAccumulator_c_wrapper_once();
+extern void _GSignalEmissionHook_c_wrapper();
+extern void _GSignalEmissionHook_c_wrapper_once();
+extern void _GToggleNotify_c_wrapper();
+extern void _GToggleNotify_c_wrapper_once();
+extern void _GTypeClassCacheFunc_c_wrapper();
+extern void _GTypeClassCacheFunc_c_wrapper_once();
+extern void _GTypeInterfaceCheckFunc_c_wrapper();
+extern void _GTypeInterfaceCheckFunc_c_wrapper_once();
+extern void _GTypePluginCompleteInterfaceInfo_c_wrapper();
+extern void _GTypePluginCompleteInterfaceInfo_c_wrapper_once();
+extern void _GTypePluginCompleteTypeInfo_c_wrapper();
+extern void _GTypePluginCompleteTypeInfo_c_wrapper_once();
+extern void _GTypePluginUnuse_c_wrapper();
+extern void _GTypePluginUnuse_c_wrapper_once();
+extern void _GTypePluginUse_c_wrapper();
+extern void _GTypePluginUse_c_wrapper_once();
+extern void _GValueTransform_c_wrapper();
+extern void _GValueTransform_c_wrapper_once();
+extern void _GWeakNotify_c_wrapper();
+extern void _GWeakNotify_c_wrapper_once();
 extern void _GChildWatchFunc_c_wrapper();
 extern void _GChildWatchFunc_c_wrapper_once();
 extern void _GClearHandleFunc_c_wrapper();
@@ -74,6 +128,8 @@ extern void _GScannerMsgFunc_c_wrapper();
 extern void _GScannerMsgFunc_c_wrapper_once();
 extern void _GSequenceIterCompareFunc_c_wrapper();
 extern void _GSequenceIterCompareFunc_c_wrapper_once();
+extern void _GSourceDisposeFunc_c_wrapper();
+extern void _GSourceDisposeFunc_c_wrapper_once();
 extern void _GSourceDummyMarshal_c_wrapper();
 extern void _GSourceDummyMarshal_c_wrapper_once();
 extern void _GSourceFunc_c_wrapper();
@@ -98,60 +154,6 @@ extern void _GUnixFDSourceFunc_c_wrapper();
 extern void _GUnixFDSourceFunc_c_wrapper_once();
 extern void _GVoidFunc_c_wrapper();
 extern void _GVoidFunc_c_wrapper_once();
-extern void _GBaseFinalizeFunc_c_wrapper();
-extern void _GBaseFinalizeFunc_c_wrapper_once();
-extern void _GBaseInitFunc_c_wrapper();
-extern void _GBaseInitFunc_c_wrapper_once();
-extern void _GBindingTransformFunc_c_wrapper();
-extern void _GBindingTransformFunc_c_wrapper_once();
-extern void _GBoxedCopyFunc_c_wrapper();
-extern void _GBoxedCopyFunc_c_wrapper_once();
-extern void _GBoxedFreeFunc_c_wrapper();
-extern void _GBoxedFreeFunc_c_wrapper_once();
-extern void _GCallback_c_wrapper();
-extern void _GCallback_c_wrapper_once();
-extern void _GClassFinalizeFunc_c_wrapper();
-extern void _GClassFinalizeFunc_c_wrapper_once();
-extern void _GClassInitFunc_c_wrapper();
-extern void _GClassInitFunc_c_wrapper_once();
-extern void _GClosureMarshal_c_wrapper();
-extern void _GClosureMarshal_c_wrapper_once();
-extern void _GClosureNotify_c_wrapper();
-extern void _GClosureNotify_c_wrapper_once();
-extern void _GInstanceInitFunc_c_wrapper();
-extern void _GInstanceInitFunc_c_wrapper_once();
-extern void _GInterfaceFinalizeFunc_c_wrapper();
-extern void _GInterfaceFinalizeFunc_c_wrapper_once();
-extern void _GInterfaceInitFunc_c_wrapper();
-extern void _GInterfaceInitFunc_c_wrapper_once();
-extern void _GObjectFinalizeFunc_c_wrapper();
-extern void _GObjectFinalizeFunc_c_wrapper_once();
-extern void _GObjectGetPropertyFunc_c_wrapper();
-extern void _GObjectGetPropertyFunc_c_wrapper_once();
-extern void _GObjectSetPropertyFunc_c_wrapper();
-extern void _GObjectSetPropertyFunc_c_wrapper_once();
-extern void _GSignalAccumulator_c_wrapper();
-extern void _GSignalAccumulator_c_wrapper_once();
-extern void _GSignalEmissionHook_c_wrapper();
-extern void _GSignalEmissionHook_c_wrapper_once();
-extern void _GToggleNotify_c_wrapper();
-extern void _GToggleNotify_c_wrapper_once();
-extern void _GTypeClassCacheFunc_c_wrapper();
-extern void _GTypeClassCacheFunc_c_wrapper_once();
-extern void _GTypeInterfaceCheckFunc_c_wrapper();
-extern void _GTypeInterfaceCheckFunc_c_wrapper_once();
-extern void _GTypePluginCompleteInterfaceInfo_c_wrapper();
-extern void _GTypePluginCompleteInterfaceInfo_c_wrapper_once();
-extern void _GTypePluginCompleteTypeInfo_c_wrapper();
-extern void _GTypePluginCompleteTypeInfo_c_wrapper_once();
-extern void _GTypePluginUnuse_c_wrapper();
-extern void _GTypePluginUnuse_c_wrapper_once();
-extern void _GTypePluginUse_c_wrapper();
-extern void _GTypePluginUse_c_wrapper_once();
-extern void _GValueTransform_c_wrapper();
-extern void _GValueTransform_c_wrapper_once();
-extern void _GWeakNotify_c_wrapper();
-extern void _GWeakNotify_c_wrapper_once();
 extern void _GAsyncReadyCallback_c_wrapper();
 extern void _GAsyncReadyCallback_c_wrapper_once();
 extern void _GBusAcquiredCallback_c_wrapper();
@@ -506,14 +508,14 @@ void _g_input_stream_close_async(GInputStream* this, int32_t arg0, GCancellable*
 		g_input_stream_close_async(this, arg0, arg1, 0, 0);
 	}
 }
-void _g_input_stream_read_all_async(GInputStream* this, uint8_t* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+void _g_input_stream_read_all_async(GInputStream* this, uint8_t** arg0, uint32_t* arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
 	if (gofunc) {
 		g_input_stream_read_all_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
 		g_input_stream_read_all_async(this, arg0, arg1, arg2, arg3, 0, 0);
 	}
 }
-void _g_input_stream_read_async(GInputStream* this, uint8_t* arg0, uint32_t arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
+void _g_input_stream_read_async(GInputStream* this, uint8_t** arg0, uint32_t* arg1, int32_t arg2, GCancellable* arg3, void* gofunc) {
 	if (gofunc) {
 		g_input_stream_read_async(this, arg0, arg1, arg2, arg3, _GAsyncReadyCallback_c_wrapper_once, gofunc);
 	} else {
