@@ -128,6 +128,8 @@ extern void _GScannerMsgFunc_c_wrapper();
 extern void _GScannerMsgFunc_c_wrapper_once();
 extern void _GSequenceIterCompareFunc_c_wrapper();
 extern void _GSequenceIterCompareFunc_c_wrapper_once();
+extern void _GSourceDisposeFunc_c_wrapper();
+extern void _GSourceDisposeFunc_c_wrapper_once();
 extern void _GSourceDummyMarshal_c_wrapper();
 extern void _GSourceDummyMarshal_c_wrapper_once();
 extern void _GSourceFunc_c_wrapper();
